@@ -36,6 +36,14 @@ def init(_mute, _env, _runstep, _task_id):
     runstep = _runstep
     global task_id
     task_id = _task_id
+    global calls
+    calls = []
+    global current_call_limit
+    current_call_limit = 0
+    global next_call_limit
+    next_call_limit = 0
+    global stdio
+    stdio = {'out': [], 'error': []}
 
 
 def get_state():
@@ -136,3 +144,24 @@ def check_lt(a, b, msg):
 
 def check_gt(a, b, msg):
     calls.extend((['checkGt', [a, b, msg]]))
+
+
+def sotest_function_standard(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+    return wrapper
+
+
+def sotest_function_authorization(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+    return wrapper
+
+
+def sotest_function_verify(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+    return wrapper
